******************************PRE_COVID ANALYSIS****************************************************************
****************************************************************************************************************
*********************Calculates man-cession correlations in the pre-Covid period to be used in figures later on
clear all
*Set Directory

gl rawdata  = "...\rawdata"
gl procdata = "...\procdata"
gl output   = "...\output"

cd "${output}"


use "${procdata}/LFS_27countries_20_64_aggregates.dta"
gen countryname="."
replace countryname="Belgium" if country=="BE"
replace countryname="Denmark" if country=="DK"
replace countryname="Germany" if country=="DE"
replace countryname="Greece" if country=="GR"
replace countryname="Spain" if country=="ES"
replace countryname="France" if country=="FR"
replace countryname="Ireland" if country=="IE"
replace countryname="Italy" if country=="IT"
replace countryname="Luxembourg" if country=="LU"
replace countryname="Netherlands" if country=="NL"
replace countryname="Austria" if country=="AT"
replace countryname="Portugal" if country=="PT"
replace countryname="Finland" if country=="FI"
replace countryname="Sweden" if country=="SE"
replace countryname="Czechia" if country=="CZ"
replace countryname="Estonia" if country=="EE"
replace countryname="Hungary" if country=="HU"
replace countryname="Latvia" if country=="LV"
replace countryname="Lithuania" if country=="LT"
replace countryname="Poland" if country=="PL"
replace countryname="Romania" if country=="RO"
replace countryname="Slovakia" if country=="SK"
replace countryname="Slovenia" if country=="SI"
replace countryname="Iceland" if country=="IS"
replace countryname="Norway" if country=="NO"
replace countryname="Switzerland" if country=="CH"
replace countryname="UK" if country=="UK"
rename country c
rename countryname country

append using "${procdata}/US_aggregates.dta" //
append using "${procdata}/Canada_aggregates.dta"
drop hours_singlemale hours_marriedmale hours_singlefemale hours_marriedfemale thours_singlemale thours_marriedmale thours_singlefemale thours_marriedfemale thours_female thours_male thours //not needed for this analysis
***************GDP data***************************************
merge 1:1 year country using "${procdata}\gdp_annual.dta"

*drop if country=="Luxembourg" //low number observations
***************************************************************

encode country,gen(C)
keep if _merge==3 //either early years before 98 where gdp occurs, or late years where LFS data is missing for countries like Turkey
*******************************Set time series*****************************************************************
***************************************************************************************************************
tsset C year, yearly
rename realgdp gdp
rename mhours hours_all
rename memp emp_all
*###############################################################################################################

gen rel_hours=hours_female/hours_male
gen rel_emp=emp_female/emp_male
gen logratioemp_fm=log(rel_emp) //or the same as difference of logs
gen logratiohours_fm=log(rel_hours)
gen l_gdp=log(gdp)

tsfilter hp hourratio_cycle=logratiohours_fm, smooth(6.25)
tsfilter hp empratio_cycle=logratioemp_fm, smooth(6.25)
tsfilter hp gdp_cycle=l_gdp, smooth(6.25)

local countrylist "Austria Belgium Switzerland Spain Finland Czechia Estonia Hungary Latvia Lithuania Romania Slovakia Slovenia Iceland Czechia Germany Denmark France  Greece Hungary Ireland Italy Luxembourg Netherlands Norway Poland Portugal Sweden UK US Canada"

*****Different mancession measures to be used in figures later on

*****Regression coefficient to be used in prediction of a recession in Figure 5: actual vs predicted
gen beta_hour=.
gen beta_emp=.
foreach c of local countrylist{
reg hourratio_cycle gdp_cycle if country=="`c'"
replace beta_hour = _b[gdp_cycle] if country=="`c'"
}

foreach c of local countrylist{
reg empratio_cycle gdp_cycle if country=="`c'"
replace beta_emp = _b[gdp_cycle] if country=="`c'"
}

****Raw correlation of relative hour/emp cycles and GDP cycles to report in Figure 3
gen corr_hour=.
gen corr_emp=.

foreach c of local countrylist{
egen corr_`c' = corr(hourratio_cycle gdp_cycle) if country=="`c'"
replace corr_hour=corr_`c' if country=="`c'"
drop corr_`c'
}


foreach c of local countrylist{
egen corr_`c' = corr(empratio_cycle gdp_cycle) if country=="`c'"
replace corr_emp=corr_`c' if country=="`c'"
drop corr_`c'
}


****some variables to be used in regressions******
gen female_hours_2019=hours_female if year==2019

collapse beta_hour corr_hour beta_emp corr_emp female_hours_2019, by(country)



save "${procdata}/precovid.dta", replace



