/* #############################################################################
Link data from different waves and clean data
############################################################################# */

* Preliminaries
clear


* Directories *
cd "${git_workdir}"



* Log File
log using "${out_dir}/Germany_dataprep.log", replace


** loading data GIP waves 43 & 45 & 47 & 49 and MCS;
use using "${local_data_encryp}/data_GIP49.dta"

append using "${local_data_encryp}/data_GIP45.dta"

append using "${local_data_encryp}/data_GIP43.dta"

append using "${local_data_encryp}/data_GIP39.dta"

append using "${local_data_encryp}/data_GIP37.dta"

append using "${local_data_encryp}/data_GIP36.dta"

append using "${local_data_encryp}/data_MCS.dta"

** merge data from wave 47: no employment, only background variables included in this wave:
merge m:1 id_g using "${local_data_encryp}/data_GIP47.dta", nogen keep(1 3)




******************************************************************************** 
* Remove temporarily saved data *
*********************************

* cap rm "${local_data_encryp}/data_GIP49.dta"
* cap rm "${local_data_encryp}/data_GIP47.dta"
* cap rm "${local_data_encryp}/data_GIP45.dta"
* cap rm "${local_data_encryp}/data_GIP43.dta"
* cap rm "${local_data_encryp}/data_GIP39.dta"
* cap rm "${local_data_encryp}/data_GIP37.dta"
* cap rm "${local_data_encryp}/data_GIP36.dta"

* cap rm "${local_data_encryp}/data_MCS.dta"




/* #############################################################################
	Cleanup of general, basic variables
############################################################################# */


*****
* sex
gen sex = gender_20 if gender_20 != .
replace sex = gender_19 if gender_19 != .
replace sex = gender_18 if gender_18 != .
replace sex = gender_17 if gender_17 != .


**************************
* birth year of respondent 
gen birth_year_cat = year_of_birth_cat_20 if year_of_birth_cat_20 != .
replace birth_year_cat = year_of_birth_cat_19 if year_of_birth_cat_19 != .
replace birth_year_cat = year_of_birth_cat_18 if year_of_birth_cat_18 != .
replace birth_year_cat = year_of_birth_cat_17 if year_of_birth_cat_17 != .


********************
* State of residence 
gen state = state_20 if state_20 != .
replace state = state_19 if state_19 != .
replace state = state_18 if state_18 != .
replace state = state_17 if state_17 != .


**********************
* Number of HH members
gen number_hh_members = number_hh_members_20 if number_hh_members_20 != .
replace number_hh_members = number_hh_members_19 if number_hh_members_19 != .
replace number_hh_members = number_hh_members_18 if number_hh_members_18 != .
replace number_hh_members = number_hh_members_17 if number_hh_members_17 != .


***************************************
** Check consistency of the measures **
***************************************


*********************
* Schooling education
gen educ_school = educ_school_20 if educ_school_20 != .
replace educ_school = educ_school_19 if educ_school_19 != .
replace educ_school = educ_school_18 if educ_school_18 != .
replace educ_school = educ_school_17 if educ_school_17 != .


***************
* Job education
gen educ_job = educ_job_20 if educ_job_20 != .
replace educ_job = educ_job_19 if educ_job_19 != .
replace educ_job = educ_job_18 if educ_job_18 != .
replace educ_job = educ_job_17 if educ_job_17 != .


*************
* Citizenship
gen german_citizenship = german_citizenship_20 if german_citizenship_20 != .
replace german_citizenship = german_citizenship_19 if german_citizenship_19 != .
replace german_citizenship = german_citizenship_18 if german_citizenship_18 != .
replace german_citizenship = german_citizenship_17 if german_citizenship_17 != .


****************
* marital status
gen marital_status = marital_status_20 if marital_status_20 != .
replace marital_status = marital_status_19 if marital_status_19 != .
replace marital_status = marital_status_18 if marital_status_18 != .
replace marital_status = marital_status_17 if marital_status_17 != .



/* #############################################################################
	Initial sample selection on existing gender, birth year and observation period 
############################################################################# */

drop if sex == .
drop if sex < 0

drop if birth_year_cat == .
drop if birth_year_cat < 0

drop if dDatum == .


/* #############################################################################
	Drop basic variables
############################################################################# */

drop marital_status_* german_citizenship_* educ_job_* educ_school_* ///
	number_hh_members_* state_* year_of_birth_cat_* gender_* occupation_*



/* #############################################################################
	Creating variables time variables
############################################################################# */

****************
* Year and month
gen year = year(dDatum) 
gen month = month(dDatum) 

*********
* Quarter
gen dateq = qofd(dDatum)
format dateq %tq

***************
* quarter dummy
gen Qt = 1 if month >= 1 & month <= 3
replace Qt = 2 if month >= 4 & month <= 6
replace Qt = 3 if month >= 7 & month <= 9
replace Qt = 4 if month >= 10 & month <= 12


**********************
* weekly time variable
gen time_week = .

replace time_week = 28 if month == 7 & year == 2018 // July 2018

replace time_week = 3 if month == 1
replace time_week = 37 if month == 9
forvalues i = 1/16 {
	replace time_week = 11+`i' if Woche == `i'
}
gen week_date = yw(year,time_week)

#delimit ;
label var week_date "Observation period" ;
label define week_vals 
3043 "Jul 2018"
3052 "Sep 2018 (fuzzy)"
3070 "Jan 2019"
3104 "Sep 2019"
3122 "Jan 2020"
3131 "March 20-26, 2020"
3132 "March 27-April 2, 2020"
3133 "April 3-9, 2020"
3134 "April 10-16, 2020"
3135 "April 17-23, 2020"
3136 "April 24-30, 2020"
3137 "May 1-7, 2020"
3138 "May 8-14, 2020"
3139 "May 15-21, 2020"
3140 "May 22-28, 2020"
3141 "May 29-June 4, 2020"
3142 "June 5-11, 2020"
3143 "June 12-18, 2020"
3144 "June 19-25, 2020"
3145 "June 26-July 2, 2020"
3146 "July 3-10, 2020"
3156 "Sep 2020" ;
label values week_date week_vals ;
#delimit cr



/* #############################################################################
	Creating variables from basic variables
############################################################################# */


*****************************
* Inidcator for being married
gen married = .
replace married = 1 if marital_status==1 | marital_status==2 | marital_status==6 | marital_status==7 // married, living with partner | married separated from spouse | currently (possibly living separately) in civil partnership 
replace married = 0 if marital_status==3 | marital_status==4 | marital_status==5 | marital_status==9 // single, never married | divorced | widowed


***********
* Education

** 1) based on US: 
gen simp_educ_US = .

// remaining education levels:
replace simp_educ_US = 0 if educ_school==1 | educ_school==2 | educ_school==3 | educ_school==4 | educ_school==7
	// still student, no degree, some school degree (Haupt- or Realschule), other degree

replace simp_educ_US = 1 if educ_school==5 | educ_school==6 						
	// Abitur/Fachhochschulreife: highest school diploma in Germany 

replace simp_educ_US = 2 if educ_job == 4 | educ_job == 5 | educ_job == 6 | educ_job == 7 | educ_job == 12
	// higher education: some college or vocational training, associates, etc
	// did not consider those who are currently in education

replace simp_educ_US = 3 if educ_job == 8 | educ_job == 9 | educ_job == 10 | educ_job == 11  
	// university degree or equivalent: BA or more (also Fachhochschule)

#delimit ;
label var simp_educ_US "4 Education groups (as in US code)" ;
label define simp_educ_US_vals 
0 "still student, no degree, some school degree (Haupt- or Realschule), other degree"
1 "Abitur/Fachhochschulreife: highest school diploma in Germany"
2 "higher education: some college or vocational training, associates, etc"
3 "university degree or equivalent: BA or more (also Fachhochschule)";
label values simp_educ_US simp_educ_US_vals ;
#delimit cr

codebook educ_school,tab(1000)
codebook educ_job,tab(1000)

tab simp_educ_US, m

tab simp_educ_US educ_school, m
tab simp_educ_US educ_job, m
** too broad categories given our data: therefore, either college or group the first two categories


** 2) Education split only by unversity degree: (as the 4 splits imply very little people in group 0 and 1)
gen college = .
replace college = 1 if educ_job == 8 | educ_job == 9 | educ_job == 10 | educ_job == 11  
	// university degree or equivalent: BA or more (also Fachhochschule)
replace college = 0 if college != 1 & simp_educ_US != .
	// include only those that also received an assignemnt in the case above 

#delimit ;
label var college "4 Education groups (as in US code)" ;
label define college_vals 
0 "no university degreee or equivalent"
1 "university degree or equivalent: BA or more (also Fachhochschule)";
label values college college_vals ;
#delimit cr


** 3) Education split by school degree, vocational training and unversity degree:
gen simp_educ = . 
replace simp_educ = 0 if educ_school==1 | educ_school==2 | educ_school==3 | educ_school==4 | educ_school==5 | educ_school==6 | educ_school==7
	// none or any school degree: still student, no degree, some school degree (Haupt- or Realschule), 
	// other degree, Abitur/Fachhochschulreife: highest school diploma in Germany 

replace simp_educ = 1 if educ_job == 4 | educ_job == 5 | educ_job == 6 | educ_job == 7 | educ_job == 12
	// higher education: some college or vocational training, associates, etc
	// did not consider those who are currently in education

replace simp_educ = 2 if educ_job == 8 | educ_job == 9 | educ_job == 10 | educ_job == 11  
	// university degree or equivalent: BA or more (also Fachhochschule)

#delimit ;
label var simp_educ "3 Education groups" ;
label define simp_educ_vals 
0 "still student, no degree, or any school degree (Haupt- or Realschule, Abitur), other degree"
1 "higher education: some college or vocational training, associates, etc"
2 "university degree or equivalent: BA or more (also Fachhochschule)";
label values simp_educ simp_educ_vals ;
#delimit cr

// define as main educational variable
rename simp_educ educ


** 4) Education - Möhring definition:
gen educ_school_only = .
replace educ_school_only = 1 if educ_school == 1 | educ_school == 2 | educ_school == 3 // low: educ_school: 1, 2, 3
replace educ_school_only = 2 if educ_school == 4 | educ_school == 7 // low: educ_school: 4, 7
replace educ_school_only = 3 if educ_school == 5 | educ_school == 6 // low: educ_school: 5, 6






/* #############################################################################
	Creating common variables from wave specific variables
############################################################################# */


************
* Employment

/* Definition of broad employment 	
- employment: 
	- FT, PT employed
	- minijob, 400-Euro Job
- non-employment:
	- early retirement (ind. if in work or non-work period) but as we condition on below 55, it is reasonable to assume that those people are still in the working period
	- in apprenticeship
	- in re-education
	- voluntary work year / voluntary military service
	- voluntary year of social work	
	- 1-Euro job (very few people)
	- irregularly employed
	- parental leave
	- student
	- pensioner
	- unemployed
	- unable to work
	- taking care of the house
*/

**********
** 1) GIP: Employment variable
gen emp_GIP = .

* Employment variable in GIP wave 37:
gen emp_temp = AA37451
replace emp_temp = 1 if emp_temp == . & AA37450_a == 1
replace emp_temp = 2 if emp_temp == . & AA37450_b == 1
replace emp_temp = 3 if emp_temp == . & AA37450_c == 1
replace emp_temp = 4 if emp_temp == . & AA37450_d == 1
replace emp_temp = 5 if emp_temp == . & AA37450_e == 1
replace emp_temp = 6 if emp_temp == . & AA37450_f == 1
replace emp_temp = 7 if emp_temp == . & AA37450_g == 1
replace emp_temp = 8 if emp_temp == . & AA37450_h == 1
replace emp_temp = 9 if emp_temp == . & AA37450_i == 1
replace emp_temp = 10 if emp_temp == . & AA37450_j == 1
replace emp_temp = 11 if emp_temp == . & AA37450_k == 1
replace emp_temp = 12 if emp_temp == . & AA37450_l == 1
replace emp_temp = 13 if emp_temp == . & AA37450_m == 1
replace emp_temp = 14 if emp_temp == . & AA37450_n == 1
replace emp_temp = 15 if emp_temp == . & AA37450_o == 1
replace emp_temp = 16 if emp_temp == . & AA37450_p == 1
replace emp_temp = 17 if emp_temp == . & AA37450_q == 1

replace emp_GIP = emp_temp if year == 2018 & month == 9
drop emp_temp


* Employment variable in GIP wave 43:
gen emp_temp = AA43451
replace emp_temp = 1 if emp_temp == . & AA43450_a == 1
replace emp_temp = 2 if emp_temp == . & AA43450_b == 1
replace emp_temp = 3 if emp_temp == . & AA43450_c == 1
replace emp_temp = 4 if emp_temp == . & AA43450_d == 1
replace emp_temp = 5 if emp_temp == . & AA43450_e == 1
replace emp_temp = 6 if emp_temp == . & AA43450_f == 1
replace emp_temp = 7 if emp_temp == . & AA43450_g == 1
replace emp_temp = 8 if emp_temp == . & AA43450_h == 1
replace emp_temp = 9 if emp_temp == . & AA43450_i == 1
replace emp_temp = 10 if emp_temp == . & AA43450_j == 1
replace emp_temp = 11 if emp_temp == . & AA43450_k == 1
replace emp_temp = 12 if emp_temp == . & AA43450_l == 1
replace emp_temp = 13 if emp_temp == . & AA43450_m == 1
replace emp_temp = 14 if emp_temp == . & AA43450_n == 1
replace emp_temp = 15 if emp_temp == . & AA43450_o == 1
replace emp_temp = 16 if emp_temp == . & AA43450_p == 1
replace emp_temp = 17 if emp_temp == . & AA43450_q == 1

replace emp_GIP = emp_temp if year == 2019 & month == 9
drop emp_temp


* Employment variable in GIP wave 49:
gen emp_temp = AA49451
replace emp_temp = 1 if emp_temp == . & AA49450_a == 1
replace emp_temp = 2 if emp_temp == . & AA49450_b == 1
replace emp_temp = 3 if emp_temp == . & AA49450_c == 1
replace emp_temp = 4 if emp_temp == . & AA49450_d == 1
replace emp_temp = 5 if emp_temp == . & AA49450_e == 1
replace emp_temp = 6 if emp_temp == . & AA49450_f == 1
replace emp_temp = 7 if emp_temp == . & AA49450_g == 1
replace emp_temp = 8 if emp_temp == . & AA49450_h == 1
replace emp_temp = 9 if emp_temp == . & AA49450_i == 1
replace emp_temp = 10 if emp_temp == . & AA49450_j == 1
replace emp_temp = 11 if emp_temp == . & AA49450_k == 1
replace emp_temp = 12 if emp_temp == . & AA49450_l == 1
replace emp_temp = 13 if emp_temp == . & AA49450_m == 1
replace emp_temp = 14 if emp_temp == . & AA49450_n == 1
replace emp_temp = 15 if emp_temp == . & AA49450_o == 1
replace emp_temp = 16 if emp_temp == . & AA49450_p == 1
replace emp_temp = 17 if emp_temp == . & AA49450_q == 1

replace emp_GIP = emp_temp if year == 2020 & month == 9

drop emp_temp


* Employment variable in GIP wave 36:
replace emp_GIP = AA36005 if year == 2018 & month == 7


* Employment variable in GIP wave 39:
replace emp_GIP = AA39005 if year == 2019 & month == 1


* Employment variable in GIP wave 45:
replace emp_GIP = AA45005 if year == 2020 & month == 1





**********
** 2) MCS: Employment variable
gen emp_MCS = .

* (i) Baseline definition of the employment status (equivalent to UK definition)
replace emp_MCS = 0 if SCDX004 >= 11 & SCDX004 <= 17 
	// same definition during all weeks: parental leave, pupil, student, pensioner, unemployed, unable to work, housewife/-men

replace emp_MCS = 1 if SCDX004 >= 18 & SCDX004 <= 24 & Woche >= 1 & Woche <= 7
	// employed in week 1 - 7 (including furloughed people and self-employed with few orders)

replace emp_MCS = 1 if SCDX004 >= 25 & SCDX004 <= 26 & Woche >= 8 & Woche <= 16
	// employed in week 8 - 16 (including furloughed people and self-employed with few orders)



**********
* 3) Broad employment measure: full-time, part-time or marginal job (minijob)
gen broad_emp = .

// GIP: FT, PT, marginal jobs in waves 39, 43, 45, 49  
replace broad_emp = 1 if (year == 2019 | year == 2020) & (month == 1 | month == 9) & (emp_GIP == 1 | emp_GIP == 2 | emp_GIP == 4)
replace broad_emp = 0 if (year == 2019 | year == 2020) & (month == 1 | month == 9) & (emp_GIP == 3 | ( emp_GIP >= 5 & emp_GIP <= 17))

// GIP: FT, PT, marginal jobs in waves 36  
replace broad_emp = 1 if year == 2018 & (month == 7 | month == 9) & (emp_GIP == 1 | emp_GIP == 2 | emp_GIP == 4)
replace broad_emp = 0 if year == 2018 & (month == 7 | month == 9) & (emp_GIP == 3 | ( emp_GIP >= 5 & emp_GIP <= 17))


// MCS: FT, PT, marginal jobs
replace broad_emp = emp_MCS if Woche != .






************************
* Hours worked last week

gen raw_hours = .

**********
** 1) GIP wave 36: daily hours worked

* get actual hours last week from daily hours last week:
// average actual hours in the reference week incl studies and commute and second job (per day, therefore multiplied with 5))
// but students and unemployed get a 0 assigned below
replace raw_hours = AC36187 if broad_emp == 1 & year == 2018 & month == 7 & AC36187 >= 0 & AC36187 <= 24 
replace raw_hours = raw_hours*5 if year == 2018 & month == 7 // hours at a regular workday - assuming 5 days per week
replace raw_hours = 97 if raw_hours >= 97 & raw_hours != . & year == 2018 & month == 7 // cap hours at 97h/week
replace raw_hours = 0 if broad_emp==0 & year == 2018 & month == 7 //unemployed and NILF get zero hours, for extensive margin


**********
** 2) MCS: hours variable

* get actual hours last week from daily hours last week:
// average actual hours in the reference week incl studies and commute and second job (per day, therefore multiplied with 5))
// but students and unemployed get a 0 assigned below
replace raw_hours = SCBX022 if broad_emp == 1 & (Woche == 5 | (Woche >= 10 & Woche <= 16)) & SCBX022 >= 0 & SCBX022 <= 24
replace raw_hours = raw_hours*5	if (Woche == 5 | (Woche >= 10 & Woche <= 16)) // hours at a regular workday - assuming 5 days per week
replace raw_hours = 97 if raw_hours >= 97 & raw_hours != . & (Woche == 5 | (Woche >= 10 & Woche <= 16)) // cap hours at 97h/week
replace raw_hours = 0 if broad_emp==0 & (Woche == 5 | (Woche >= 10 & Woche <= 16)) //unemployed and NILF get zero hours, for extensive margin


**********
** 3) Broad hours index

* Baseline: hyperbolic sine transformation
gen hours = ln(raw_hours + (1+raw_hours^2)^(1/2))

* Alternative: log: ln(1+raw_hours) [See: MacCurdy and Pencavel JPE 1986]
gen log_hours = ln(1+raw_hours)







**********
* Industry

// Information available in wave 49 & 43 (and 37)

/* using the following classifications (as in UK, except cat 20 and 21 not defined): 
1- A Agriculture, forestry and fishing
2- B Mining & quarrying
3- C Manufacturing
4- D Energy, Electricity, gas & air con supply
5- E Water supply, sewerage & waste
6- F Construction
7- G Distribution
8- H Transport & storage
9- I Accommodation
10- J Information & communication
11- K Financial & insurance services
12- L Real estate services
13- M Professional, scientific & technical activities
14- N Admin & suppport services
15- O Public admin & defence (taken defense activities out in sample selection above - code: 8422)
16- P Education
17- Q Health & social work
18- R Arts, entertainment & recreation
19- S Other service activities
*/

** 1) Generate industry information from waves 49 & 43 (and 37)

gen simp_ind = .
// wave 49 (Sep 2020)
replace simp_ind = AA49458 if (AA49458 > 0 & AA49458 < 20) & year == 2020 & month == 9 // take care of missings as well

// wave 43 (Sep 2019)
replace simp_ind = AA43458 if (AA43458 > 0 & AA43458 < 20) & year == 2019 & month == 9 // take care of missings as well

// wave 37 (Sep 2018)
replace simp_ind = AA37458 if (AA37458 > 0 & AA37458 < 20) & year == 2018 & month == 9 // take care of missings as well

#delimit ;
label var simp_ind "1-digit Industry code" ;
label define simp_ind_vals 
1 "Agriculture, forestry and fishing"
2 "Mining & quarrying"
3 "Manufacturing"
4 "Electricity, gas & air con supply"
5 "Water supply, sewerage & waste"
6 "Construction"
7 "Distribution"
8 "Transport & storage"
9 "Accommodation & food services"
10 "Information & communication"
11 "Financial & insurance services"
12 "Real estate services"
13 "Professional, scientific & technical activities"
14 "Admin & suppport services"
15 "Public admin & defence (w/o military)"
16 "Education"
17 "Health & social work"
18 "Arts, entertainment & recreation"
19 "Other service activities"
99 "unknown industry" ;
label values simp_ind simp_ind_vals ;
#delimit cr



** 2) Use the industry information from waves 37, 43 and 49 for other waves and MCS survey:

/* procedure: 
- (i) use first the information from the past 
- (ii) if there is no past information available, use future industry information
*/

* (i) Infer industry information from the past:
forvalues i = 1/23{ 
	sort id_g week_date
	by id_g: gen temp = 1 if id_g == id_g[_n-1] & simp_ind == . & simp_ind[_n-1] != .
	replace simp_ind = simp_ind[_n-1] if temp == 1

	drop temp
}

* (ii) Infer industry information from the future:
forvalues i = 1/23{ 
	sort id_g week_date
	by id_g: gen temp = 1 if id_g == id_g[_n+1] & simp_ind == . & simp_ind[_n+1] != .
	replace simp_ind = simp_ind[_n+1] if temp == 1

	drop temp
}


** 3) Assign everybody else for whom we do not have industry information into the "unknown industry" class:
// - different procedure from US and other countries because we do not have industry information in each observation period.
// Therefore, we do not want to select only the non-employed into the regression sample in the periods in which we do not know 
// the industry if we don't have info on industry from other periods. 
replace simp_ind = 99 if (simp_ind == . & broad_emp != .) 

** generate worktype only from industry **
gen work_type = .
replace work_type = simp_ind




********************
* Child in HH (<16y)

gen child_grp = .

**********
** 1) GIP: Child in HH (<16y)

// we have information for 4 other household members as well as relation to the HH member and age. 
// we also have information on number of HH members. possibly problematic if total number of HH members larger than 5

// AAxx415a: 3 - 1st person is child & AAxx413a: 1 - 1st person is below 16 years
	// possible Robustness: AAxx415a: we could in addition to child (3) also use categories: 
	// - grandchild (8), other relative (9) or other person who is non relative (10) 



* wave 37: (i) assigning children below 16 in HH *
// 1st person in HH:
replace child_grp = 1 if AA37415a == 3 & AA37413a == 1 
// 2nd person in HH:
replace child_grp = 1 if AA37415b == 3 & AA37413b == 1 // same categories and definition as for first person in HH 
// 3rd person in HH:
replace child_grp = 1 if AA37415c == 3 & AA37413c == 1 // same categories and definition as for first person in HH 
// 4th person in HH:
replace child_grp = 1 if AA37415d == 3 & AA37413d == 1 // same categories and definition as for first person in HH 

* wave 37: (ii) assigning no children in HH *
// baseline: conservative - only those who do not have a child below 16 in HH as one of the first four ppl in the HH as indicated above (child_grp == .)
// AND who have less than 5 HH members in the HH 
replace child_grp = 0 if child_grp == . & number_hh_members >= 1 & number_hh_members <= 4 & year == 2018 & month == 9




* wave 43: (i) assigning children below 16 in HH (same setup as in wave 37)*
// 1st person in HH:
replace child_grp = 1 if AA43415a == 3 & AA43413a == 1
// 2nd person in HH:
replace child_grp = 1 if AA43415b == 3 & AA43413b == 1 
// 3rd person in HH:
replace child_grp = 1 if AA43415c == 3 & AA43413c == 1 
// 4th person in HH:
replace child_grp = 1 if AA43415d == 3 & AA43413d == 1 

* wave 43: (ii) assigning no children in HH *
// baseline: conservative - only those who do not have a child below 16 in HH as one of the first four ppl in the HH as indicated above (child_grp == .)
// AND who have less than 5 HH members in the HH
replace child_grp = 0 if child_grp == . & number_hh_members >= 1 & number_hh_members <= 4 & year == 2019 & month == 9


* wave 49: (i) assigning children below 16 in HH (same setup as in wave 37)*
// 1st person in HH:
replace child_grp = 1 if AA49415a == 3 & AA49413a == 1
// 2nd person in HH:
replace child_grp = 1 if AA49415b == 3 & AA49413b == 1
// 3rd person in HH:
replace child_grp = 1 if AA49415c == 3 & AA49413c == 1 
// 4th person in HH:
replace child_grp = 1 if AA49415d == 3 & AA49413d == 1 

* wave 49: (ii) assigning no children in HH *
// baseline: conservative - only those who do not have a child below 16 in HH as one of the first four ppl in the HH as indicated above (child_grp == .)
// AND who have less than 5 HH members in the HH 
replace child_grp = 0 if child_grp == . & number_hh_members >= 1 & number_hh_members <= 4 & year == 2020 & month == 9



**********
** 2) MCS: Child in HH (<16y)

// we have information on children in HH below 16
** (i) assigning children in HH **
replace child_grp = 1 if SCFX001 >= 1 & SCFX001 <= 3 // at least 1 or more kids below 16 in the HH

** (ii) assigning no children in HH **
replace child_grp = 0 if SCFX001 == 0



**********
** 3) Birth history of children in HH: 
// for July 2018, Jan 2019 and Jan 2020 as child group not defined in those waves
// for Sep 2018, 2019 and 2020: for those for whom we cannot identify if child lives in HH 

* create child group indicator from Sep 2018 for July 2018:
sort id_g week_date
gen temp_child_grp_sep18 = child_grp[_n+1] if year == 2018 & month == 7 & year[_n+1] == 2018 & month[_n+1] == 9 & id_g == id_g[_n+1] & child_grp[_n+1] != .

gen child_ind = .

forvalues i = 33/42 {
	* July 2018: 
	// children born in 2018 assumed to be born before July wave (correct with Sep wave info below)
	// leaving out those who were born in second half of 2002 (still 15 in July)
	replace child_ind = 1 if (child_ind == . | child_ind == 0) & LC470`i'a >= 2003 & LC470`i'a <= 2017 & LC470`i'c == 1 & year == 2018 & month == 7
	replace child_ind = 1 if (child_ind == . | child_ind == 0) & LC470`i'a == 2018 & LC470`i'c == 1 & year == 2018 & month == 7 & temp_child_grp_sep18 != 0
	replace child_ind = 0 if child_ind == . & LC470`i'a > 0 & LC470`i'a != . & year == 2018 & month == 7


	* Sep 2018 - focus only on those who have missing child indicator: 
	// children born in 2018 assumed to be born before Sep wave 
	// leaving out those who were born after Sep 2002
	replace child_ind = 1 if (child_ind == . | child_ind == 0) & child_grp == . & LC470`i'a >= 2003 & LC470`i'a <= 2018 & LC470`i'c == 1 & year == 2018 & month == 9
		// LC470`i'a: birthyear between 2003 and 2018; LC470`i'c == 1 lives in the same HH
	replace child_ind = 0 if child_ind == . & child_grp == . & LC470`i'a > 0 & LC470`i'a != . & year == 2018 & month == 9


	* January 2019: 
	replace child_ind = 1 if (child_ind == . | child_ind == 0) & LC470`i'a >= 2003 & LC470`i'a <= 2018 & LC470`i'c == 1 & year == 2019 & month == 1
	replace child_ind = 0 if child_ind == . & LC470`i'a > 0 & LC470`i'a != . & year == 2019 & month == 1


	* Sep 2019 - focus only on those who have missing child indicator: 
	// children born in 2019 assumed to be born before Sep wave 
	// leaving out those who were born after Sep 2003
	replace child_ind = 1 if (child_ind == . | child_ind == 0) & child_grp == . & LC470`i'a >= 2004 & LC470`i'a <= 2019 & LC470`i'c == 1 & year == 2019 & month == 9
		// LC470`i'a: birthyear between 2004 and 2019; LC470`i'c == 1 lives in the same HH
	replace child_ind = 0 if child_ind == . & child_grp == . & LC470`i'a > 0 & LC470`i'a != . & year == 2019 & month == 9


	* January 2020: 
	replace child_ind = 1 if (child_ind == . | child_ind == 0) & LC470`i'a >= 2004 & LC470`i'a <= 2019 & LC470`i'c == 1 & year == 2020 & month == 1
	replace child_ind = 0 if child_ind == . & LC470`i'a > 0 & LC470`i'a != . & year == 2020 & month == 1


	* Sep 2020 - focus only on those who have missing child indicator: 
	// children born in 2020 assumed to be born before Sep wave 
	// leaving out those who were born after Sep 2004
	replace child_ind = 1 if (child_ind == . | child_ind == 0) & child_grp == . & LC470`i'a >= 2005 & LC470`i'a <= 2020 & LC470`i'c == 1 & year == 2020 & month == 9
		// LC470`i'a: birthyear between 2005 and 2020; LC470`i'c == 1 lives in the same HH
	replace child_ind = 0 if child_ind == . & child_grp == . & LC470`i'a > 0 & LC470`i'a != . & year == 2020 & month == 9

}

replace child_grp = child_ind if child_grp == .


**********
** 4) Infer child in HH variable within MCS:

tab child_grp week_date,m

* inferring from t-1:
forvalues i = 1/16{ 
	sort id_g week_date
	by id_g: gen temp = 1 if id_g == id_g[_n-1] & child_grp == . & child_grp[_n-1] != . & Woche != . & Woche[_n-1] != .
	replace child_grp = child_grp[_n-1] if temp == 1
	
	drop temp	
}

* inferring from t+1:
forvalues i = 1/16{ 
	sort id_g week_date
	by id_g: gen temp = 1 if id_g == id_g[_n+1] & child_grp == . & child_grp[_n+1] != . & Woche != . & Woche[_n+1] != .
	replace child_grp = child_grp[_n+1] if temp == 1
	
	drop temp	
}



**********
** 5) Infer child in HH variable from past:

* Sep 2020 - rely on information from all 16 MCS waves:
forvalues i = 1/16{ 
	sort id_g week_date
	by id_g: gen temp = 1 if id_g == id_g[_n-`i'] & child_grp == . & child_grp[_n-`i'] != . & year == 2020 & month == 9 & Woche[_n-`i'] != .
	replace child_grp = child_grp[_n-`i'] if temp == 1
	
	drop temp
}

* Jan 2020 - rely on information from Sep 2019:
sort id_g week_date
by id_g: gen temp = 1 if id_g == id_g[_n-1] & child_grp == . & child_grp[_n-1] != . & year == 2020 & month == 1 & year[_n-1] == 2019 & month[_n-1] == 9
replace child_grp = child_grp[_n-1] if temp == 1

drop temp

* Jan 2019 - rely on information from Sep 2018:
sort id_g week_date
by id_g: gen temp = 1 if id_g == id_g[_n-1] & child_grp == . & child_grp[_n-1] != . & year == 2019 & month == 1 & year[_n-1] == 2018 & month[_n-1] == 9
replace child_grp = child_grp[_n-1] if temp == 1

drop temp



**********
** 6) Infer child in HH variable from close future:

* July 2018 - rely on Sep 2018:
sort id_g week_date
by id_g: gen temp = 1 if id_g == id_g[_n+1] & child_grp == . & child_grp[_n+1] != . & year == 2018 & year[_n+1] == 2018 & month == 7 & month[_n+1] == 9
replace child_grp = child_grp[_n+1] if temp == 1
drop temp


* Jan 2019 - rely on Sep 2019:
sort id_g week_date
by id_g: gen temp = 1 if id_g == id_g[_n+1] & child_grp == . & child_grp[_n+1] != . & year == 2019 & year[_n+1] == 2019 & month == 1 & month[_n+1] == 9
replace child_grp = child_grp[_n+1] if temp == 1
drop temp


* Jan 2020 - rely on MCS:
forvalues i = 1/17{ 
	sort id_g week_date
	by id_g: gen temp = 1 if id_g == id_g[_n+`i'] & child_grp == . & child_grp[_n+`i'] != . & year == 2020 & month == 1 & Woche[_n+`i'] != . 
	replace child_grp = child_grp[_n+`i'] if temp == 1
	
	drop temp
}


* Jan 2020 - rely on Sep 2020:
forvalues i = 1/17{ 
	sort id_g week_date
	by id_g: gen temp = 1 if id_g == id_g[_n+`i'] & child_grp == . & child_grp[_n+`i'] != . & year == 2020 & month == 1 & year[_n+`i'] == 2020 & month[_n+`i'] == 9 
	replace child_grp = child_grp[_n+`i'] if temp == 1
	
	drop temp
}


**************
* Cohabitation

// if partner and if partner lives in the same HH

gen cohab = .

**********
** 1) GIP: Cohabitation

/* 
only relation with first 4 HH members in wave 37, 43, 49: 
I assume that if cohabitation with a partner, then one would mention the person as one of the first 4 HH members.
*/

* assigning partner in HH - wave 37:
// 1st person in HH:
replace cohab = 1 if AA37415a == 1 | AA37415a == 2 // AA37415a: 1 - spouse / 2 - partner, both not conditioned on sex of spouse/partner

// 2nd person in HH:
replace cohab = 1 if AA37415b == 1 | AA37415b == 2 // same categories and definition as for first person in HH 

// 3rd person in HH:
replace cohab = 1 if AA37415c == 1 | AA37415c == 2 // same categories and definition as for first person in HH 

// 4th person in HH:
replace cohab = 1 if AA37415d == 1 | AA37415d == 2 // same categories and definition as for first person in HH 

** (ii) assigning no partner in HH if did not specify a partner above**
replace cohab = 0 if cohab == . & year == 2018 & month == 9


* assigning partner in HH - wave 43:
// 1st person in HH:
replace cohab = 1 if AA43415a == 1 | AA43415a == 2 // AA43415a: 1 - spouse / 2 - partner, both not conditioned on sex of spouse/partner

// 2nd person in HH:
replace cohab = 1 if AA43415b == 1 | AA43415b == 2 // same categories and definition as for first person in HH 

// 3rd person in HH:
replace cohab = 1 if AA43415c == 1 | AA43415c == 2 // same categories and definition as for first person in HH 

// 4th person in HH:
replace cohab = 1 if AA43415d == 1 | AA43415d == 2 // same categories and definition as for first person in HH 

** (ii) assigning no partner in HH if did not specify a partner above**
replace cohab = 0 if cohab == . & year == 2019 & month == 9


* assigning partner in HH - wave 49:
// 1st person in HH:
replace cohab = 1 if AA49415a == 1 | AA49415a == 2 // AA49415a: 1 - spouse / 2 - partner, both not conditioned on sex of spouse/partner

// 2nd person in HH:
replace cohab = 1 if AA49415b == 1 | AA49415b == 2 // same categories and definition as for first person in HH 

// 3rd person in HH:
replace cohab = 1 if AA49415c == 1 | AA49415c == 2 // same categories and definition as for first person in HH 

// 4th person in HH:
replace cohab = 1 if AA49415d == 1 | AA49415d == 2 // same categories and definition as for first person in HH 

** (ii) assigning no partner in HH if did not specify a partner above**
replace cohab = 0 if cohab == . & year == 2020 & month == 9



**********
** 2) MCS: Cohabitation

** (i) assigning partner in HH **
replace cohab = 1 if SCFX004 == 1 & SCFX005 == 1 & Woche != . // SCFX004: 1 has partner & SCFX005: 1 lives in same HH
replace cohab = 0 if cohab == . & SCFX004 == 2 & Woche != .  // answered: no partner
replace cohab = 0 if SCFX004 == 1 & SCFX005 >= 2 & SCFX005 <= 4 & Woche != .  // answered: partner but either in another HH, further away, foreign country



**********
**** define robustness cohabitation variable only relying on observed cohabitation status:
gen cohab_rob = cohab
**********



**********
** 3) Cohabitation not defined in all MCS waves:

tab cohab week_date,m


** Iteration within MCS first:
gen cohab_temp = .

forvalues i = 1/16{ 
	* inferring from past week, i.e. t-1:
	sort id_g week_date
	by id_g: gen temp = 1 if id_g == id_g[_n-`i'] & cohab == . & cohab_temp == . & cohab[_n-`i'] != . & Woche != . & Woche[_n-`i'] != .
	replace cohab_temp = cohab[_n-`i'] if temp == 1
	drop temp	

	* inferring from future week, i.e. t+1:
	sort id_g week_date
	by id_g: gen temp = 1 if id_g == id_g[_n+`i'] & cohab == . & cohab_temp == . & cohab[_n+`i'] != . & Woche != . & Woche[_n+`i'] != .
	replace cohab_temp = cohab[_n+`i'] if temp == 1
	drop temp	
}

replace cohab = cohab_temp if Woche != . & cohab == .

drop cohab_temp


** Information from Sep 2020 for MCS observations:
forvalues i = 1/17{ 
	sort id_g week_date
	by id_g: gen temp = 1 if id_g == id_g[_n+`i'] & cohab == . & cohab[_n+`i'] != . & Woche != . & year[_n+`i'] == 2020 & month[_n+`i'] == 9 
	replace cohab = cohab[_n+`i'] if temp == 1
	
	drop temp
}



**********
** 4) Cohabitation not defined in all GIP waves:

** Inferring cohabitation status from close future:

* July 2018 - rely on Sep 2018:
sort id_g week_date
by id_g: gen temp = 1 if id_g == id_g[_n+1] & cohab == . & cohab[_n+1] != . & year == 2018 & year[_n+1] == 2018 & month == 7 & month[_n+1] == 9
replace cohab = cohab[_n+1] if temp == 1
drop temp


** Inferring cohabitation status from close past:

* Jan 2019 - rely on Sep 2018:
sort id_g week_date
by id_g: gen temp = 1 if id_g == id_g[_n-1] & cohab == . & cohab[_n-1] != . & year == 2019 & year[_n-1] == 2018 & month == 1 & month[_n-1] == 9
replace cohab = cohab[_n-1] if temp == 1
drop temp


* Jan 2020 - rely on Sep 2019:
sort id_g week_date
by id_g: gen temp = 1 if id_g == id_g[_n-1] & cohab == . & cohab[_n-1] != . & year == 2020 & year[_n-1] == 2019 & month == 1 & month[_n-1] == 9
replace cohab = cohab[_n-1] if temp == 1
drop temp


* Jan 2020 - rely on Mannheim Corona Study and implicitly Sep 2020:
forvalues i = 1/17{ 
	sort id_g week_date
	by id_g: gen temp = 1 if id_g == id_g[_n+`i'] & cohab == . & cohab[_n+`i'] != . & year == 2020 & month == 1 & Woche[_n+`i'] != . 
	replace cohab = cohab[_n+`i'] if temp == 1
	
	drop temp
}


* Jan 2019 - rely on Sep 2019:
sort id_g week_date
by id_g: gen temp = 1 if id_g == id_g[_n+1] & cohab == . & cohab[_n+1] != . & year == 2019 & year[_n+1] == 2019 & month == 1 & month[_n+1] == 9
replace cohab = cohab[_n+1] if temp == 1
drop temp



********************************
* Race / Migration / citizenship


* Citizenship - available in all GIP waves & MCS:
gen simp_citizen = .
replace simp_citizen = 1 if german_citizenship == 1 | german_citizenship == 2 
replace simp_citizen = 0 if german_citizenship == 3


* Migration background:
// use birth location for all those, for whom it's available (GIP wave 47)
// create indicator for born in Germany (needs to be moved to data prep later):
gen born_germany = .
// initialize the preloaded birth location (preloaded from previous years in wave 47)
replace born_germany = 1 if PLGebOrt == 1 // born in Germany
replace born_germany = 0 if PLGebOrt == 2 | PLGebOrt == 3 // born outside of Germany
// Overwrite if update of prelaoded birth location or if missing part information now available 
* relevant age range (born after 1945) relies only variable: LC47004 
replace born_germany = 1 if LC47004 == 1 // born in Germany
replace born_germany = 0 if LC47004 == 2 | LC47004 == 3 // born outside of Germany

// generate migration background with born in Germany variable if available:
// imperfect measure, but better than only conditioning on citizenship
gen simp_migration = .
replace simp_migration = 0 if simp_citizen == 1
replace simp_migration = 1 if simp_citizen == 0 
replace simp_migration = 1 if simp_citizen == 1 & born_germany == 0 



/* #############################################################################
	Keep only relevant variables
############################################################################# */


// Drop employment variables from GIP
drop AA49450_a AA49450_b AA49450_c AA49450_d AA49450_e AA49450_f AA49450_g AA49450_h AA49450_i AA49450_j AA49450_k AA49450_l AA49450_m AA49450_n AA49450_o AA49450_p AA49450_q 
drop AA49451

drop AA43450_a AA43450_b AA43450_c AA43450_d AA43450_e AA43450_f AA43450_g AA43450_h AA43450_i AA43450_j AA43450_k AA43450_l AA43450_m AA43450_n AA43450_o AA43450_p AA43450_q 
drop AA43451

drop AA39005



/* #############################################################################
	Sample selection 1
############################################################################# */


********************************
* Pandemic Treatment and Control
gen Dt = .

replace Dt = 0 if (year == 2018 & (month == 7 | month == 9) ) | year == 2019 | (year==2020 & month<=2) // pre-pandemic = 0
replace Dt = 1 if year==2020 & month>=3 & month<= 9 // post-pandemic = 1


*****************************
* Selection on time variables
keep if Dt != .

// select only those who are observed:
drop if dDatum == .




/* #############################################################################
	Save dataset for cross country analysis
############################################################################# */


****************************
* Restrict population sample

// keeping those born between 1955 - 1999: Aged 20/21 - 64/65 in 2020 
keep if birth_year_cat >= 5 & birth_year_cat <= 13


// save data set encrypted locally for the event study plots and regression analyses:
save "${local_data_encryp}/Germany_clean_paneldata_2064.dta", replace





/* #############################################################################
	Sample selection 2
############################################################################# */


****************************
* Restrict population sample

// keeping those born between 1965 - 1994: Aged 26 - 55 in 2020 
keep if birth_year_cat >= 7 & birth_year_cat <= 12 


/* #############################################################################
	Weights from MCS Data 
############################################################################# */

gen wi_rake_alt = wi_rake

** create artifical weight of 1 for all regular bi-monthly surveys:
replace wi_rake_alt = 1 if wi_rake_alt == .


/* #############################################################################
	Save clean dataset
############################################################################# */

// save data set encrypted locally for the event study plots and regression analyses:
save "${local_data_encryp}/Germany_clean_paneldata.dta", replace



/* #############################################################################
############################################################################# */
log close