

* Preliminaries
cls
clear all
set maxvar 20000
set matsize 2000
set emptycells drop

* Data *
use "$out_dir/dta/NLcrosssecinddataset.dta", clear

**********************
* Sample and Settings*
**********************


* Population Sample
local lagegroup = 25 
local agegroup =  55 
keep if age>=`lagegroup' & age<`agegroup'

* Time Index 
gen time_var = ym(year,month) 
gen sdate= string(time_var, "%tmmy") 
labmask time_var, val(sdate) // label time periods with month-year

local small_cutoff = 5       // transition baby to middle school age
 
* rename variables // specific to LISS data
rename age_youngest_child yngch
rename hasjob broad_emp 
rename hours hours_nl
rename gender sex 

********************************************************************************
* No More Settings Below Here * Automated Given Above *
******************************************************************************** 
* Create Variables *
********************

* Pandemic Treatment and Control
gen Dt = . // quatertly change
replace Dt = 1 if year==2020 & month>=4 & month<=9 // post-pandemic = 1, 2020Q2 + 2020Q3
replace Dt = 0 if (year==2020 & month>=1 & month<=2) | (year==2019 & month==12)  // pre-pandemic = 0,  < 2020Q1 !! I don't include March
replace Dt = 0 if year==2019  // pre-pandemic = 0

* Simplified Child Groups
gen child_grp = .
replace child_grp = 1 if yngch< `small_cutoff' //small kids
replace child_grp = 2 if yngch>=`small_cutoff' & yngch<18 // 5-17 school age
replace child_grp = 0 if yngch>=18 /* & yngch<99 // youngest child >= 18 yo, same as no children */ // age = . if no child

* Broad Hours Index
* (Broad Hours Index assigned 0 to those unemployed or NILF. For measurement, use hours worked last week rather than usual hours worked, given unusual short term nature of recession)
gen raw_hours_usual = hours_nl
replace raw_hours_usual = 0 if broad_emp == 0 & hours_sample == 1 & year == 2020 // hours worked last week, careful with samples April 2019 and June 2020
replace raw_hours_usual = . if raw_hours_usual>(24-8)*7 // drop those with impossibly high hours 

gen raw_hours_lwk = hours_c // covid module
replace raw_hours_lwk = raw_hours_usual if year <= 2019 // main modumle (usual hours)
replace raw_hours_lwk = 0 if broad_emp == 0 & raw_hours_lwk==. & (month == 3 | month == 4) & EmploymentStatusMarch == 0 & corona_sample == 1  // hours worked last week, careful with samples April 2019 and June 2020
replace raw_hours_lwk = . if raw_hours_lwk>(24-8)*7 // drop those with impossibly high hours

* create hours index
gen hours_usual = ln(raw_hours_usual + (1+raw_hours_usual^2)^(1/2)) // hyperbolic sine transformation to approximate log funciton
gen hours_lwk = ln(raw_hours_lwk + (1+raw_hours_lwk^2)^(1/2)) // hyperbolic sine transformation to approximate log funciton
gen hours_lwk_simp = ln(raw_hours_lwk + 1) // log funciton

* has reported hours in the covid module 
gen corona_sample_may = raw_hours_lwk!=. & month == 5
bysort nomem_encr: egen isin_covidm = max(corona_sample_may)

* Education
gen simp_educ = (education>=2)  if education!=7 // < less than hs diploma or equivalent vs hs diploma or equivalent
replace simp_educ = 0 if  education>=8 & education<=9  // < less than hs diploma or equivalent
replace simp_educ = 2 if  education>=3 & education<=4 // some college or associatess
replace simp_educ = 3 if  education>=5 & education<=6 // BA or more

gen college= simp_educ == 3 if simp_educ!=. //  less than BA (0) vs BA or more (1)

* Simple race
gen simp_race = .
replace simp_race = 0 if herkomstgroep==0
replace simp_race = 1 if herkomstgroep!=0 & herkomstgroep!=.

* Age groups
gen age_grp = ceil((age+1)/5-5)

* Marital status
replace married = 1 if burgstat == 1 // cohabitation or married

* Occupations
gen occ = prof if year == 2019 
replace occ = 0 if  hours_nl == 0 & hours_sample == 1 & year <= 2019 & occ  == . // synthetic cat
bysort nomem_encr: egen occ1= max(occ)			
replace occ1 = prof if year == 2018 &  (occ1==. | occ1==0) & prof!=.
bysort nomem_encr: egen occ2= max(occ1)	
replace occ2 = prof if year == 2017 &  (occ2==. | occ2==0) & prof!=.
bysort nomem_encr: egen occ3= max(occ2)
replace occ3 = prof if year == 2016 &  (occ3==. | occ3==0) & prof!=.
bysort nomem_encr: egen simp_occ= max(occ3)
drop occ1 occ2 occ3

* Industry
gen sect = sector if year == 2019 
replace sect = 0 if  hours_nl == 0 & hours_sample == 1 & year <= 2019 & sect ==.  // synthetic cat
bysort nomem_encr: egen sect1= max(sect)
replace sect1 = sector if year == 2018 &  (sect1==. | sect1==0) & prof!=.
bysort nomem_encr: egen sect2= max(sect1)	
replace sect2 = sector if year == 2017 &  (sect2==. | sect2==0) & prof!=.
bysort nomem_encr: egen sect3= max(sect2)
replace sect3 = sector if year == 2016 &  (sect3==. | sect3==0) & prof!=.
bysort nomem_encr: egen simp_ind= max(sect3)
drop sect1 sect2 sect3

* Compound work type groups for regressions, simple industry x simple occupation 
egen work_type = group(simp_occ simp_ind), label 

* Quarterly dummies 
gen Qt = .
replace Qt = 1 if month>=1  & month<=3
replace Qt = 2 if month>=4  & month<=6
replace Qt = 3 if month>=7  & month<=9
replace Qt = 4 if month>=10 & month<=12

* Quarterly Time Series
gen time_qts = yq(year,Qt) // quarterly time
gen sdate_qts= string(time_qts, "%tq") 
labmask time_qts, val(sdate_qts) // label time periods with quarterly labels


// Summer Education Sector Indicator
gen sum_edu = 0
replace sum_edu = 1 if simp_ind==12 & month>=6 & month<=8

// Telecommuting
gen TC_now     = .
replace TC_now = 0 if hours_h == 0 & EmploymentStatus<=2 //non-tele employed
replace TC_now = 1 if hours_h!=. & hours_h>0  & EmploymentStatus<=2 //tele employed
egen telecom = max(TC_now), by(nomem_encr) // assigned telecomutting if ever did during May - Oct
