/* #############################################################################
Regression setup: telecommuting
############################################################################# */


* Preliminaries
clear


* Directories *
cd "${local_workdir}"


* Log File
log using "${out_dir}/UK_DiD_telecom.log", replace

* Load saved dataset
use "${local_workdir}/UK_cleaned_data.dta", clear




********************************************************************************
* How many men and women work 0 hours conditional on being employed working *
********************************************************************************

preserve


* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.

keep if broad_emp == 1
keep if hours_lwk != .

gen Zerohours = 0
replace Zerohours = 1 if hours_lwk == 0

tab Zerohours dateq ,m

collapse Zerohours [fw=PWT18], by(dateq child_grp sex)

gen diff = .
sort dateq child_grp sex
by dateq child_grp: replace diff = - Zerohours + Zerohours[_n+1] if dateq == dateq[_n+1] &  child_grp == child_grp[_n+1]

export excel using "${out_dir}/UK_DiD.xlsx",  sheet("footnote - 0hours of employed",replace) first(var) sheetmodify


restore




********************************************************************************
* Regressions: Effect of home office on hours worked if employed *
******************************************************************

// Spec 1: Hours Telecommuting Regression - Baseline definition of telecommuting 
********************************************************************************
preserve


* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.

drop if telecom == . // keep only those who report basis of work

* Population
 reg hours_lwk Dt##ib1.sex#ib0.telecom c.time_var_reg#ib1.sex                                        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pweight=PWT18],  robust 
est store bench  
matrix table_bench = r(table) //store reg results

 reg hours_lwk Dt##ib1.sex#ib0.telecom  c.time_var_reg#ib1.sex  Dt##i.work_type                     i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pweight=PWT18],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
 reg hours_lwk Dt##ib1.sex#ib0.child_grp#ib0.telecom  c.time_var_reg#ib1.sex                        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pweight=PWT18],  robust 
est store kid
matrix table_kid = r(table) //store reg results

 reg hours_lwk Dt##ib1.sex#ib0.child_grp#ib0.telecom  c.time_var_reg#ib1.sex  Dt##i.work_type        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pweight=PWT18],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 



* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/UK_DiD.xlsx" , sheet("Table 16") modify  // replace first time around
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Pop - No telecommuting (bench)"
putexcel B2=table_bench[1,15] 
putexcel B3=table_bench[2,15] 
putexcel B4=table_bench[4,15] 

putexcel C1 =  "Pop - Telecommuting (bench)"
putexcel C2=table_bench[1,16] 
putexcel C3=table_bench[2,16] 
putexcel C4=table_bench[4,16] 


putexcel D1 =  "No Kids - No telecommuting  (bench)"
putexcel D2=table_kid[1,43]   
putexcel D3=table_kid[2,43] 
putexcel D4=table_kid[4,43] 

putexcel E1 =  "No Kids - Telecommuting  (bench)"
putexcel E2=table_kid[1,44]   
putexcel E3=table_kid[2,44] 
putexcel E4=table_kid[4,44] 


putexcel F1 =  "Small Kids - No telecommuting  (bench)"
putexcel F2=table_kid[1,45]   
putexcel F3=table_kid[2,45] 
putexcel F4=table_kid[4,45] 

putexcel G1 =  "Small Kids - Telecommuting  (bench)"
putexcel G2=table_kid[1,46]   
putexcel G3=table_kid[2,46] 
putexcel G4=table_kid[4,46] 


putexcel H1 =  "School Kids - No telecommuting  (bench)"
putexcel H2=table_kid[1,47]   
putexcel H3=table_kid[2,47] 
putexcel H4=table_kid[4,47] 

putexcel I1 =  "School Kids - Telecommuting  (bench)"
putexcel I2=table_kid[1,48]   
putexcel I3=table_kid[2,48] 
putexcel I4=table_kid[4,48] 



//...and with occ controls
putexcel J1 =  "Pop - No telecommuting (work type)"
putexcel J2=table_bench_occ[1,15] 
putexcel J3=table_bench_occ[2,15] 
putexcel J4=table_bench_occ[4,15] 

putexcel K1 =  "Pop - Telecommuting (work type)"
putexcel K2=table_bench_occ[1,16] 
putexcel K3=table_bench_occ[2,16] 
putexcel K4=table_bench_occ[4,16] 


putexcel L1 =  "No Kids - No telecommuting  (work type)"
putexcel L2=table_kid_occ[1,43]   
putexcel L3=table_kid_occ[2,43] 
putexcel L4=table_kid_occ[4,43] 

putexcel M1 =  "No Kids - Telecommuting  (work type)"
putexcel M2=table_kid_occ[1,44]   
putexcel M3=table_kid_occ[2,44] 
putexcel M4=table_kid_occ[4,44] 


putexcel N1 =  "Small Kids - No telecommuting  (work type)"
putexcel N2=table_kid_occ[1,45]   
putexcel N3=table_kid_occ[2,45] 
putexcel N4=table_kid_occ[4,45] 

putexcel O1 =  "Small Kids - Telecommuting  (work type)"
putexcel O2=table_kid_occ[1,46]   
putexcel O3=table_kid_occ[2,46] 
putexcel O4=table_kid_occ[4,46] 


putexcel P1 =  "School Kids - No telecommuting  (work type)"
putexcel P2=table_kid_occ[1,47]   
putexcel P3=table_kid_occ[2,47] 
putexcel P4=table_kid_occ[4,47] 

putexcel Q1 =  "School Kids - Telecommuting  (work type)"
putexcel Q2=table_kid_occ[1,48]   
putexcel Q3=table_kid_occ[2,48] 
putexcel Q4=table_kid_occ[4,48] 




******************************************************************************************************
* Regression: Effect of home office on hours worked if employed and working strictly positive hours
****************************************************************************************


// Spec 3: Hours Telecommuting Regression - Baseline definition of telecommuting & conditioning on positive hours
*****************************************************************************************************************

preserve

* drop those with zero hours:
drop if hours_lwk == 0


* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.

drop if telecom == . // keep only those who report basis of work

* Population
 reg hours_lwk Dt##ib1.sex#ib0.telecom c.time_var_reg#ib1.sex                                        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pweight=PWT18],  robust 
est store bench  
matrix table_bench = r(table) //store reg results

 reg hours_lwk Dt##ib1.sex#ib0.telecom  c.time_var_reg#ib1.sex  Dt##i.work_type                     i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pweight=PWT18],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
 reg hours_lwk Dt##ib1.sex#ib0.child_grp#ib0.telecom  c.time_var_reg#ib1.sex                        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pweight=PWT18],  robust 
est store kid
matrix table_kid = r(table) //store reg results

 reg hours_lwk Dt##ib1.sex#ib0.child_grp#ib0.telecom  c.time_var_reg#ib1.sex  Dt##i.work_type        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pweight=PWT18],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 



* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/UK_DiD.xlsx" , sheet("footnote- Table 16 - excl0hours") modify  // replace first time around
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"

* Regression Results
putexcel B1 =  "Pop - No telecommuting (bench)"
putexcel B2=table_bench[1,15] 
putexcel B3=table_bench[2,15] 
putexcel B4=table_bench[4,15] 

putexcel C1 =  "Pop - Telecommuting (bench)"
putexcel C2=table_bench[1,16] 
putexcel C3=table_bench[2,16] 
putexcel C4=table_bench[4,16] 


putexcel D1 =  "No Kids - No telecommuting  (bench)"
putexcel D2=table_kid[1,43]   
putexcel D3=table_kid[2,43] 
putexcel D4=table_kid[4,43] 

putexcel E1 =  "No Kids - Telecommuting  (bench)"
putexcel E2=table_kid[1,44]   
putexcel E3=table_kid[2,44] 
putexcel E4=table_kid[4,44] 


putexcel F1 =  "Small Kids - No telecommuting  (bench)"
putexcel F2=table_kid[1,45]   
putexcel F3=table_kid[2,45] 
putexcel F4=table_kid[4,45] 

putexcel G1 =  "Small Kids - Telecommuting  (bench)"
putexcel G2=table_kid[1,46]   
putexcel G3=table_kid[2,46] 
putexcel G4=table_kid[4,46] 


putexcel H1 =  "School Kids - No telecommuting  (bench)"
putexcel H2=table_kid[1,47]   
putexcel H3=table_kid[2,47] 
putexcel H4=table_kid[4,47] 

putexcel I1 =  "School Kids - Telecommuting  (bench)"
putexcel I2=table_kid[1,48]   
putexcel I3=table_kid[2,48] 
putexcel I4=table_kid[4,48] 



//...and with occ controls
putexcel J1 =  "Pop - No telecommuting (work type)"
putexcel J2=table_bench_occ[1,15] 
putexcel J3=table_bench_occ[2,15] 
putexcel J4=table_bench_occ[4,15] 

putexcel K1 =  "Pop - Telecommuting (work type)"
putexcel K2=table_bench_occ[1,16] 
putexcel K3=table_bench_occ[2,16] 
putexcel K4=table_bench_occ[4,16] 


putexcel L1 =  "No Kids - No telecommuting  (work type)"
putexcel L2=table_kid_occ[1,43]   
putexcel L3=table_kid_occ[2,43] 
putexcel L4=table_kid_occ[4,43] 

putexcel M1 =  "No Kids - Telecommuting  (work type)"
putexcel M2=table_kid_occ[1,44]   
putexcel M3=table_kid_occ[2,44] 
putexcel M4=table_kid_occ[4,44] 


putexcel N1 =  "Small Kids - No telecommuting  (work type)"
putexcel N2=table_kid_occ[1,45]   
putexcel N3=table_kid_occ[2,45] 
putexcel N4=table_kid_occ[4,45] 

putexcel O1 =  "Small Kids - Telecommuting  (work type)"
putexcel O2=table_kid_occ[1,46]   
putexcel O3=table_kid_occ[2,46] 
putexcel O4=table_kid_occ[4,46] 


putexcel P1 =  "School Kids - No telecommuting  (work type)"
putexcel P2=table_kid_occ[1,47]   
putexcel P3=table_kid_occ[2,47] 
putexcel P4=table_kid_occ[4,47] 

putexcel Q1 =  "School Kids - Telecommuting  (work type)"
putexcel Q2=table_kid_occ[1,48]   
putexcel Q3=table_kid_occ[2,48] 
putexcel Q4=table_kid_occ[4,48] 






******************************************************************************************************
* Regression: Effect of home office on hours worked if employed: Telecommuting x college
****************************************************************************************


// Spec 4: Hours Telecommuting Regression - baseline telecom x college  
**********************************************************************
preserve


* Additional sample restrictions
drop if work_type==. // keep regression samples consistent across specifications
drop if child_grp==.

drop if telecom == . // keep only those who report basis of work

* Population
reg hours_lwk Dt##ib1.sex#ib0.telecom#college c.time_var_reg#ib1.sex                                        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pweight=PWT18],  robust 
est store bench  
matrix table_bench = r(table) //store reg results

reg hours_lwk Dt##ib1.sex#ib0.telecom#college  c.time_var_reg#ib1.sex  Dt##i.work_type                     i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pweight=PWT18],  robust  
est store bench_occ
matrix table_bench_occ = r(table) //store reg results


* By Child Group
reg hours_lwk Dt##ib1.sex#ib0.child_grp#ib0.telecom#college  c.time_var_reg#ib1.sex                        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pweight=PWT18],  robust 
est store kid
matrix table_kid = r(table) //store reg results

reg hours_lwk Dt##ib1.sex#ib0.child_grp#ib0.telecom#college  c.time_var_reg#ib1.sex  Dt##i.work_type        i.sum_edu i.Qt i.age_grp i.simp_educ i.simp_race  i.married [pweight=PWT18],  robust 
est store  kid_occ
matrix table_kid_occ = r(table) //store reg results

restore 



* Store Coefficients, Standard Errors, and P-Values
// Benchmark...
putexcel set "${out_dir}/UK_DiD.xlsx" , sheet("Table 18") modify  // replace first time around
putexcel A1 =  "Sample:" // row labels
putexcel A2 =  "Coefficient"
putexcel A3 =  "std error"
putexcel A4 =  "p-value"


* Regression Results
putexcel B1 =  "Pop - No telecommuting - No College (bench)"
putexcel B2=table_bench[1,29] 
putexcel B3=table_bench[2,29] 
putexcel B4=table_bench[4,29] 

putexcel C1 =  "Pop - No telecommuting - College (bench)"
putexcel C2=table_bench[1,30] 
putexcel C3=table_bench[2,30] 
putexcel C4=table_bench[4,30] 

putexcel D1 =  "Pop - Telecommuting - No College (bench)"
putexcel D2=table_bench[1,31]   
putexcel D3=table_bench[2,31] 
putexcel D4=table_bench[4,31] 

putexcel E1 =  "Pop - Telecommuting - College  (bench)"
putexcel E2=table_bench[1,32]   
putexcel E3=table_bench[2,32] 
putexcel E4=table_bench[4,32] 



putexcel F1 =  "No kids - No telecommuting - No College (bench)"
putexcel F2=table_kid[1,85] 
putexcel F3=table_kid[2,85] 
putexcel F4=table_kid[4,85] 

putexcel G1 =  "No kids - No telecommuting - College (bench)"
putexcel G2=table_kid[1,86] 
putexcel G3=table_kid[2,86] 
putexcel G4=table_kid[4,86] 

putexcel H1 =  "No kids - Telecommuting - No College (bench)"
putexcel H2=table_kid[1,87]   
putexcel H3=table_kid[2,87] 
putexcel H4=table_kid[4,87] 

putexcel I1 =  "No kids - Telecommuting - College  (bench)"
putexcel I2=table_kid[1,88]   
putexcel I3=table_kid[2,88] 
putexcel I4=table_kid[4,88] 


putexcel J1 =  "Small kids - No telecommuting - No College (bench)"
putexcel J2=table_kid[1,89] 
putexcel J3=table_kid[2,89] 
putexcel J4=table_kid[4,89] 

putexcel K1 =  "Small kids - No telecommuting - College (bench)"
putexcel K2=table_kid[1,90] 
putexcel K3=table_kid[2,90] 
putexcel K4=table_kid[4,90] 

putexcel L1 =  "Small kids - Telecommuting - No College (bench)"
putexcel L2=table_kid[1,91]   
putexcel L3=table_kid[2,91] 
putexcel L4=table_kid[4,91] 

putexcel M1 =  "Small kids - Telecommuting - College  (bench)"
putexcel M2=table_kid[1,92]   
putexcel M3=table_kid[2,92] 
putexcel M4=table_kid[4,92] 


putexcel N1 =  "School Kids - No telecommuting - No College (bench)"
putexcel N2=table_kid[1,93] 
putexcel N3=table_kid[2,93] 
putexcel N4=table_kid[4,93] 

putexcel O1 =  "School Kids - No telecommuting - College (bench)"
putexcel O2=table_kid[1,94] 
putexcel O3=table_kid[2,94] 
putexcel O4=table_kid[4,94] 

putexcel P1 =  "School Kids - Telecommuting - No College (bench)"
putexcel P2=table_kid[1,95]   
putexcel P3=table_kid[2,95] 
putexcel P4=table_kid[4,95] 

putexcel Q1 =  "School Kids - Telecommuting - College  (bench)"
putexcel Q2=table_kid[1,96]   
putexcel Q3=table_kid[2,96] 
putexcel Q4=table_kid[4,96] 



//...and with occ controls
putexcel R1 =  "Pop - No telecommuting - No College (worktype)"
putexcel R2=table_bench_occ[1,29] 
putexcel R3=table_bench_occ[2,29] 
putexcel R4=table_bench_occ[4,29] 

putexcel S1 =  "Pop - No telecommuting - College (worktype)"
putexcel S2=table_bench_occ[1,30] 
putexcel S3=table_bench_occ[2,30] 
putexcel S4=table_bench_occ[4,30] 

putexcel T1 =  "Pop - Telecommuting - No College (worktype)"
putexcel T2=table_bench_occ[1,31]   
putexcel T3=table_bench_occ[2,31] 
putexcel T4=table_bench_occ[4,31] 

putexcel U1 =  "Pop - Telecommuting - College  (worktype)"
putexcel U2=table_bench_occ[1,32]   
putexcel U3=table_bench_occ[2,32] 
putexcel U4=table_bench_occ[4,32] 



putexcel V1 =  "No kids - No telecommuting - No College (worktype)"
putexcel V2=table_kid_occ[1,85] 
putexcel V3=table_kid_occ[2,85] 
putexcel V4=table_kid_occ[4,85] 

putexcel W1 =  "No kids - No telecommuting - College (worktype)"
putexcel W2=table_kid_occ[1,86] 
putexcel W3=table_kid_occ[2,86] 
putexcel W4=table_kid_occ[4,86] 

putexcel X1 =  "No kids - Telecommuting - No College (worktype)"
putexcel X2=table_kid_occ[1,87]   
putexcel X3=table_kid_occ[2,87] 
putexcel X4=table_kid_occ[4,87] 

putexcel Y1 =  "No kids - Telecommuting - College  (worktype)"
putexcel Y2=table_kid_occ[1,88]   
putexcel Y3=table_kid_occ[2,88] 
putexcel Y4=table_kid_occ[4,88] 


putexcel Z1 =  "Small kids - No telecommuting - No College (worktype)"
putexcel Z2=table_kid_occ[1,89] 
putexcel Z3=table_kid_occ[2,89] 
putexcel Z4=table_kid_occ[4,89] 

putexcel AA1 =  "Small kids - No telecommuting - College (worktype)"
putexcel AA2=table_kid_occ[1,90] 
putexcel AA3=table_kid_occ[2,90] 
putexcel AA4=table_kid_occ[4,90] 

putexcel AB1 =  "Small kids - Telecommuting - No College (worktype)"
putexcel AB2=table_kid_occ[1,91]   
putexcel AB3=table_kid_occ[2,91] 
putexcel AB4=table_kid_occ[4,91] 

putexcel AC1 =  "Small kids - Telecommuting - College  (worktype)"
putexcel AC2=table_kid_occ[1,92]   
putexcel AC3=table_kid_occ[2,92] 
putexcel AC4=table_kid_occ[4,92] 


putexcel AD1 =  "School Kids - No telecommuting - No College (worktype)"
putexcel AD2=table_kid_occ[1,93] 
putexcel AD3=table_kid_occ[2,93] 
putexcel AD4=table_kid_occ[4,93] 

putexcel AE1 =  "School Kids - No telecommuting - College (worktype)"
putexcel AE2=table_kid_occ[1,94] 
putexcel AE3=table_kid_occ[2,94] 
putexcel AE4=table_kid_occ[4,94] 

putexcel AF1 =  "School Kids - Telecommuting - No College (worktype)"
putexcel AF2=table_kid_occ[1,95]   
putexcel AF3=table_kid_occ[2,95] 
putexcel AF4=table_kid_occ[4,95] 

putexcel AG1 =  "School Kids - Telecommuting - College  (worktype)"
putexcel AG2=table_kid_occ[1,96]   
putexcel AG3=table_kid_occ[2,96] 
putexcel AG4=table_kid_occ[4,96] 





********************************************************************************
********************************************************************************
log close






